
// ListEngines.java
// Andrew Davison, Jan 2012, as@fivedots.coe.psu.ac.th

/* Lists all the available synthesizers and their voices, 
   and all the English recognizers.

   Uses Cloud Garden's TalkingJava implementation of JSAPI
   (http://www.cloudgarden.com/JSAPI/)
*/


import javax.speech.*;
import javax.speech.recognition.*;
import javax.speech.synthesis.*;
import java.util.*;



public class ListEngines 
{
  
  public static void main(String[] args) 
  {
    // report all synthesizers
    EngineList list = Central.availableSynthesizers(null);
    for(int i = 0; i < list.size(); i++) {
      System.out.println("\nSynthesizer " + (i+1) + ":");
      System.out.println("  " + list.elementAt(i));
      listVoices((SynthesizerModeDesc)list.elementAt(i));
    }
    
    // report on all recognizers
    //list = Central.availableRecognizers( 
    //                new RecognizerModeDesc(Locale.ENGLISH, Boolean.TRUE));
    list = Central.availableRecognizers(null);
    for(int i = 0; i < list.size(); i++) {
      System.out.println("\nRecognizer " + (i+1) + ":");
      System.out.println("  " + list.elementAt(i));
      listProfiles((RecognizerModeDesc)list.elementAt(i));
    }
    System.exit(0);
  }  // end of main()


  private static void listVoices(SynthesizerModeDesc desc)
  {
    try {
      Synthesizer synth = Central.createSynthesizer(desc);
      synth.allocate();
      synth.resume();
      synth.waitEngineState(Synthesizer.ALLOCATED);
      SynthesizerProperties props = synth.getSynthesizerProperties();

      /* Need to get the Descriptor again after creating the engine
         in order to access the voices */
      desc = (SynthesizerModeDesc)synth.getEngineModeDesc();
      Voice[] vs = desc.getVoices();
      for(int i=0; i < vs.length; i++)
        System.out.println("    Voice: \"" + vs[i].getName() + "\"");

      synth.deallocate();
      synth.waitEngineState(Synthesizer.DEALLOCATED);
    } 
    catch(Exception e) {
      e.printStackTrace();
    }
  }  // end of listVoices()



  private static void listProfiles(RecognizerModeDesc desc)
  {
    try {
      Recognizer recg = Central.createRecognizer(desc);
      recg.allocate();
      recg.resume();
      recg.waitEngineState(Synthesizer.ALLOCATED);
      RecognizerProperties props = recg.getRecognizerProperties();

      /* Need to get the Descriptor again after creating the engine
         in order to access the profiles */
      desc = (RecognizerModeDesc)recg.getEngineModeDesc();
      SpeakerProfile[] profs = desc.getSpeakerProfiles();
      for(int i=0; i < profs.length; i++)
        System.out.println("    Profile: \"" + profs[i].getName() + "\"");

      recg.deallocate();
      recg.waitEngineState(Synthesizer.DEALLOCATED);
    } 
    catch(Exception e) {
      e.printStackTrace();
    }
  }  // end of listProfiles()


}  // end of ListEngines class